Plan
====================

.. _permitted-return-types:
.. csv-table:: Table of permitted plan return types
   :header: "Plan format", "Key"
   :widths: 25, 10

   "Native dataclass format", "native"
   "JSON formatted plan", "json"
   "XML formatted plan", "xml"
   "CSV formatted plan", "csv"
   "PDF formatted plan", "pdf"
   "Google Earth KML formatted plan", "kml"
   "X-Plane FMS (8, 9 & 10) formatted plan", "xplane"
   "X-Plane 11 formatted plan", "xplane11"
   "FS2004/FS9 formatted plan", "fs9"
   "FSX XML formatted plan", "fsx"
   "Squawkbox formatted plan", "squawkbox"
   "X-FMC formatted plan", "xfmc"
   "PMDG rte formatted plan", "pmdg"
   "Airbus X formatted plan", "airbusx"
   "QualityWings formatted plan", "qualitywings"
   "iFly 747 (.route) formatted plan", "ifly747"
   "FlightGear formatted plan (version 2 XML)", "flightgear"
   "TFDi Design 717 (version 1 XML)", "tfdi717"
   "Infinite Flight", "infiniteflight"


.. automodule:: flightplandb.plan
   :members:
   :undoc-members:
